import { TextFieldProps, TextField, CheckboxProps, FormControlLabelProps, SelectProps, FormControlProps, IconButtonProps, FormLabelProps, SwitchProps, AutocompleteProps, SliderProps, ToggleButtonGroupProps, ToggleButtonProps } from '@mui/material';
import { FieldValues, FieldPath, UseControllerProps, FieldError, Control, UseFormProps, SubmitHandler, SubmitErrorHandler, UseFormReturn, PathValue } from 'react-hook-form';
export * from 'react-hook-form';
import { ReactNode, RefAttributes, PropsWithChildren, FormHTMLAttributes, FormEventHandler, CSSProperties } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { FieldValues as FieldValues$1 } from 'react-hook-form/dist/types/fields';
import { DatePickerProps, DatePickerSlotsComponentsProps } from '@mui/x-date-pickers/DatePicker';
import { DateValidationError, DateTimeValidationError, TimeValidationError } from '@mui/x-date-pickers';
import { MobileDatePickerProps, MobileDatePickerSlotsComponentsProps } from '@mui/x-date-pickers/MobileDatePicker';
import { DateTimePickerProps, DateTimePickerSlotsComponentsProps } from '@mui/x-date-pickers/DateTimePicker';
import { TimePickerProps, TimePickerSlotsComponentsProps } from '@mui/x-date-pickers/TimePicker';

type TextFieldElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<TextFieldProps, 'name'> & {
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    name: TName;
    parseError?: (error: FieldError) => ReactNode;
    control?: Control<TFieldValues>;
    component?: typeof TextField;
};
type TextFieldElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: TextFieldElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const TextFieldElement: TextFieldElementComponent;

type FormContainerProps<T extends FieldValues$1 = FieldValues$1> = PropsWithChildren<UseFormProps<T> & {
    onSuccess?: SubmitHandler<T>;
    onError?: SubmitErrorHandler<T>;
    FormProps?: FormHTMLAttributes<HTMLFormElement>;
    handleSubmit?: FormEventHandler<HTMLFormElement>;
    formContext?: UseFormReturn<T>;
}>;
declare function FormContainer<TFieldValues extends FieldValues$1 = FieldValues$1>({ handleSubmit, children, FormProps, formContext, onSuccess, onError, ...useFormProps }: PropsWithChildren<FormContainerProps<TFieldValues>>): react_jsx_runtime.JSX.Element;

declare const defaultErrorMessages$2: {
    [v in NonNullable<DateValidationError>]: string;
};

type DatePickerElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, TDate = PathValue<TFieldValues, TName>> = Omit<DatePickerProps<TDate>, 'value' | 'slotProps'> & {
    name: TName;
    required?: boolean;
    isDate?: boolean;
    parseError?: (error: FieldError | DateValidationError) => ReactNode;
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    control?: Control<TFieldValues>;
    inputProps?: TextFieldProps;
    helperText?: TextFieldProps['helperText'];
    textReadOnly?: boolean;
    slotProps?: Omit<DatePickerSlotsComponentsProps<TDate>, 'textField'>;
    overwriteErrorMessages?: typeof defaultErrorMessages$2;
};
type DatePickerElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: DatePickerElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const DatePickerElement: DatePickerElementComponent;

type MobileDatePickerElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, TDate = PathValue<TFieldValues, TName>> = Omit<MobileDatePickerProps<TDate>, 'value' | 'slotProps'> & {
    name: TName;
    required?: boolean;
    isDate?: boolean;
    parseError?: (error: FieldError) => ReactNode;
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    control?: Control<TFieldValues>;
    inputProps?: TextFieldProps;
    helperText?: TextFieldProps['helperText'];
    slotProps?: Omit<MobileDatePickerSlotsComponentsProps<TDate>, 'textField'>;
    overwriteErrorMessages?: typeof defaultErrorMessages$2;
};
type MobileDatePickerElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: MobileDatePickerElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const MobileDatePickerElement: MobileDatePickerElementComponent;

declare const defaultErrorMessages$1: {
    [v in NonNullable<DateTimeValidationError>]: string;
};

type DateTimePickerElementProps<TFieldValues extends FieldValues$1 = FieldValues$1, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, TDate = PathValue<TFieldValues, TName>> = Omit<DateTimePickerProps<TDate>, 'value' | 'slotProps'> & {
    name: TName;
    required?: boolean;
    isDate?: boolean;
    parseError?: (error: FieldError) => ReactNode;
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    control?: Control<TFieldValues>;
    inputProps?: TextFieldProps;
    helperText?: TextFieldProps['helperText'];
    textReadOnly?: boolean;
    slotProps?: Omit<DateTimePickerSlotsComponentsProps<TDate>, 'textField'>;
    overwriteErrorMessages?: typeof defaultErrorMessages$1;
};
type DateTimePickerElementComponent = <TFieldValues extends FieldValues$1 = FieldValues$1, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: DateTimePickerElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const DateTimePickerElement: DateTimePickerElementComponent;

declare const defaultErrorMessages: {
    [v in NonNullable<TimeValidationError>]: string;
};

type TimePickerElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, TDate = PathValue<TFieldValues, TName>> = Omit<TimePickerProps<TDate>, 'value' | 'renderInput'> & {
    name: TName;
    required?: boolean;
    isDate?: boolean;
    parseError?: (error: FieldError) => ReactNode;
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    control?: Control<TFieldValues>;
    inputProps?: TextFieldProps;
    helperText?: TextFieldProps['helperText'];
    textReadOnly?: boolean;
    slotProps?: Omit<TimePickerSlotsComponentsProps<TDate>, 'textField'>;
    overwriteErrorMessages?: typeof defaultErrorMessages;
};
type TimePickerElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: TimePickerElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const TimePickerElement: TimePickerElementComponent;

type CheckboxElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<CheckboxProps, 'name'> & {
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    name: TName;
    parseError?: (error: FieldError) => ReactNode;
    label?: FormControlLabelProps['label'];
    helperText?: string;
    control?: Control<TFieldValues>;
    labelProps?: Omit<FormControlLabelProps, 'label' | 'control'>;
};
type CheckboxElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: CheckboxElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const CheckboxElement: CheckboxElementComponent;

type SelectElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<TextFieldProps, 'name' | 'type' | 'onChange'> & {
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    name: TName;
    options?: readonly {
        id: string | number;
        label: string | number;
        disabled?: boolean;
    }[] | readonly any[];
    valueKey?: string;
    labelKey?: string;
    type?: 'string' | 'number';
    parseError?: (error: FieldError) => ReactNode;
    objectOnChange?: boolean;
    onChange?: (value: any) => void;
    control?: Control<TFieldValues>;
};
type SelectElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: SelectElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const SelectElement: SelectElementComponent;

type CheckboxButtonGroupProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = {
    options: {
        id: string | number;
        label: string;
    }[] | any[];
    helperText?: ReactNode;
    name: TName;
    required?: boolean;
    parseError?: (error: FieldError) => ReactNode;
    label?: string;
    labelKey?: string;
    valueKey?: string;
    onChange?: (data: any) => void;
    returnObject?: boolean;
    disabled?: boolean;
    row?: boolean;
    control?: Control<TFieldValues>;
    rules?: UseControllerProps<TFieldValues, TName>['rules'];
    checkboxColor?: CheckboxProps['color'];
    labelProps?: Omit<FormControlLabelProps, 'label' | 'control'>;
};
type CheckboxButtonGroupComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: CheckboxButtonGroupProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const CheckboxButtonGroup: CheckboxButtonGroupComponent;

type MultiSelectElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<SelectProps, 'value'> & {
    options: {
        id: string | number;
        label: string;
    }[] | any[];
    label?: string;
    itemKey?: string;
    itemValue?: string;
    itemLabel?: string;
    required?: boolean;
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    name: TName;
    parseError?: (error: FieldError) => ReactNode;
    minWidth?: number;
    menuMaxHeight?: number;
    menuMaxWidth?: number;
    helperText?: ReactNode;
    showChips?: boolean;
    preserveOrder?: boolean;
    control?: Control<TFieldValues>;
    showCheckbox?: boolean;
    formControlProps?: Omit<FormControlProps, 'fullWidth' | 'variant'>;
};
type MultiSelectElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: MultiSelectElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const MultiSelectElement: MultiSelectElementComponent;

type PasswordElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = TextFieldElementProps<TFieldValues, TName> & {
    iconColor?: IconButtonProps['color'];
    renderIcon?: (password: boolean) => ReactNode;
};
type PasswordElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: PasswordElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const PasswordElement: PasswordElementComponent;

type RadioButtonGroupProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = {
    options: {
        label: string;
        id: string | number;
    }[] | any[];
    helperText?: ReactNode;
    name: TName;
    required?: boolean;
    parseError?: (error: FieldError) => ReactNode;
    label?: string;
    labelKey?: string;
    valueKey?: string;
    type?: 'number' | 'string';
    emptyOptionLabel?: string;
    onChange?: (value: any) => void;
    returnObject?: boolean;
    row?: boolean;
    control?: Control<TFieldValues>;
    labelProps?: Omit<FormControlLabelProps, 'label' | 'control' | 'value'>;
    formLabelProps?: Omit<FormLabelProps, 'required' | 'error'>;
    disabled?: boolean;
};
type RadioButtonGroupComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: RadioButtonGroupProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const RadioButtonGroup: RadioButtonGroupComponent;

type SwitchElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<FormControlLabelProps, 'control'> & {
    name: TName;
    control?: Control<TFieldValues>;
    switchProps?: SwitchProps;
};
type SwitchElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: SwitchElementProps<TFieldValues, TName> & RefAttributes<HTMLLabelElement>) => JSX.Element;
declare const SwitchElement: SwitchElementComponent;

type PasswordRepeatElementProps<TFieldValues extends FieldValues = FieldValues, TConfirmPasswordName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, TPasswordName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = PasswordElementProps<TFieldValues, TConfirmPasswordName> & {
    passwordFieldName: TPasswordName;
    customInvalidFieldMessage?: string;
};
type PasswordRepeatElementComponent = <TFieldValues extends FieldValues = FieldValues, TConfirmPasswordName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, TPasswordName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: PasswordRepeatElementProps<TFieldValues, TConfirmPasswordName, TPasswordName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const PasswordRepeatElement: PasswordRepeatElementComponent;

type AutoDefault = {
    id: string | number;
    label: string;
};
type AutocompleteElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>, Value = AutoDefault | string | any, Multiple extends boolean | undefined = boolean | undefined, DisableClearable extends boolean | undefined = boolean | undefined, FreeSolo extends boolean | undefined = boolean | undefined> = {
    name: TName;
    control?: Control<TFieldValues>;
    options: Value[];
    loading?: boolean;
    multiple?: Multiple;
    matchId?: boolean;
    loadingIndicator?: ReactNode;
    rules?: UseControllerProps<TFieldValues, TName>['rules'];
    parseError?: (error: FieldError) => ReactNode;
    required?: boolean;
    label?: TextFieldProps['label'];
    showCheckbox?: boolean;
    autocompleteProps?: Omit<AutocompleteProps<Value, Multiple, DisableClearable, FreeSolo>, 'name' | 'options' | 'loading' | 'renderInput'>;
    textFieldProps?: Omit<TextFieldProps, 'name' | 'required' | 'label'>;
};
type AutocompleteElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: AutocompleteElementProps<TFieldValues, TName, AutoDefault | string | any, boolean | undefined, boolean | undefined, boolean | undefined> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const AutocompleteElement: AutocompleteElementComponent;

type SliderElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<SliderProps, 'control'> & {
    name: TName;
    control?: Control<TFieldValues>;
    label?: string;
    rules?: UseControllerProps<TFieldValues, TName>['rules'];
    parseError?: (error: FieldError) => ReactNode;
    required?: boolean;
    formControlProps?: FormControlProps;
};
type SliderElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: SliderElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const SliderElement: SliderElementComponent;

type SingleToggleButtonProps = Omit<ToggleButtonProps, 'value' | 'children'> & {
    id: number | string;
    label: ReactNode;
};
type ToggleButtonGroupElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = ToggleButtonGroupProps & {
    required?: boolean;
    label?: string;
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    name: TName;
    parseError?: (error: FieldError) => ReactNode;
    control?: Control<TFieldValues>;
    options: SingleToggleButtonProps[];
    formLabelProps?: FormLabelProps;
    helperText?: string;
    enforceAtLeastOneSelected?: boolean;
};
declare function ToggleButtonGroupElement<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: ToggleButtonGroupElementProps<TFieldValues, TName>): react_jsx_runtime.JSX.Element;

type TextareaAutosizeElementProps<TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>> = Omit<TextFieldProps, 'name' | 'type'> & {
    validation?: UseControllerProps<TFieldValues, TName>['rules'];
    name: TName;
    parseError?: (error: FieldError) => ReactNode;
    control?: Control<TFieldValues>;
    resizeStyle?: CSSProperties['resize'];
};
type TextareaAutosizeElementComponent = <TFieldValues extends FieldValues = FieldValues, TName extends FieldPath<TFieldValues> = FieldPath<TFieldValues>>(props: TextareaAutosizeElementProps<TFieldValues, TName> & RefAttributes<HTMLDivElement>) => JSX.Element;
declare const TextareaAutosizeElement: TextareaAutosizeElementComponent;

type FormErrorProviderProps = {
    onError: (error: FieldError) => string | undefined;
};
declare function FormErrorProvider({ onError, children, }: PropsWithChildren<FormErrorProviderProps>): react_jsx_runtime.JSX.Element;
declare const useFormError: () => (error: FieldError) => string | undefined;

export { AutocompleteElement, AutocompleteElementProps, CheckboxButtonGroup, CheckboxButtonGroupProps, CheckboxElement, CheckboxElementProps, DatePickerElement, DatePickerElementProps, DateTimePickerElement, DateTimePickerElementProps, FormContainer, FormContainerProps, FormErrorProvider, FormErrorProviderProps, MobileDatePickerElement, MobileDatePickerElementProps, MultiSelectElement, MultiSelectElementProps, PasswordElement, PasswordElementProps, PasswordRepeatElement, PasswordRepeatElementProps, RadioButtonGroup, RadioButtonGroupProps, SelectElement, SelectElementProps, SliderElement, SliderElementProps, SwitchElement, SwitchElementProps, TextFieldElement, TextFieldElementProps, TextareaAutosizeElement, TextareaAutosizeElementProps, TimePickerElement, TimePickerElementProps, ToggleButtonGroupElement, ToggleButtonGroupElementProps, useFormError };
